powered by
get_glimpse retrieves the first rows of a table of the Swiss Parliament WebServices and allows a first insight into the data structure.
get_glimpse
get_glimpse(table, rows = 20, Language = "DE")
name of the table to glimpse into. For an overview of available tables use get_tables().
get_tables()
number of records to download. Maximum is 1000.
filter rows by language. Possible are DE, FR, IT, RM, and EN.
DE
FR
IT
RM
EN
A tibble of different length and variable composition.
# NOT RUN { # Short excerpt of table "Person" get_glimpse(table = "Person") # }
Run the code above in your browser using DataLab