get_glimpse2: Retrieve the first rows of an OpenParlData resource

View source: R/get_glimpse.R

get_glimpse2R Documentation

Retrieve the first rows of an OpenParlData resource

Description

get_glimpse2 retrieves the first rows of a resource provided by the OpenParlData.ch REST API and allows a first insight into its data structure.

Usage

get_glimpse2(table, rows = 20)

Arguments

table

name of the OpenParlData resource to glimpse into. For an overview of available endpoints use get_tables2().

rows

number of records to download. Maximum is 1000.

Value

A tibble containing up to rows records. Column composition depends on the selected OpenParlData resource.

Examples

## Not run: 
# Short excerpt of OpenParlData resource "persons"
get_glimpse2(table = "persons")

## End(Not run)

swissparl documentation built on March 4, 2026, 9:07 a.m.