get_related_tables2: List related tables available

View source: R/get_data.R

get_related_tables2R Documentation

Description

get_related_tables2 returns the names of related tables that are available for an OpenParlData record.

Usage

get_related_tables2(res)

Arguments

res

an OpenParlData record (typically one row) as returned by get_data2().

Value

A sorted character vector containing the names of available related tables for the provided record.

Examples

## Not run: 
# Retrieve one person
res <- get_data2("persons", firstname = "Gerhard", lastname = "Andrey")

# List available related resources for that record
get_related_tables2(res)

## End(Not run)

swissparl documentation built on March 4, 2026, 9:07 a.m.