| get_tables | R Documentation |
get_tables retrieves the names of the available tables of the Swiss Parliament WebServices.
get_tables()
A sorted character vector containing the names of the available tables.
## Not run:
# Get all available tables
get_tables()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.