get_variables: Retrieve available variables

View source: R/get_variables.R

get_variablesR Documentation

Retrieve available variables

Description

get_variables retrieves the variable names of a table of the Swiss Parliament WebServices.

Usage

get_variables(table, pb.pos = NULL, pb = NULL)

Arguments

table

name of the table to be queried. For an overview of available tables use get_tables().

pb.pos

value for the progress bar. Not to be specified outside of get_overview().

pb

progress bar object. Not to be specified outside of get_overview().

Value

A sorted character vector containing the names of the variables.

Examples

## Not run: 
# Get variables of table "Person"
get_variables(table = "Person")

## End(Not run)

swissparl documentation built on March 4, 2026, 9:07 a.m.