get_variables2: Retrieve available variables from an OpenParlData endpoint

get_variables2R Documentation

Retrieve available variables from an OpenParlData endpoint

Description

get_variables2 retrieves the field names of a resource provided by the OpenParlData.ch REST API.

Usage

get_variables2(table, pb.pos = NULL, pb = NULL)

Arguments

table

name of the OpenParlData resource to be queried. For an overview of available endpoints use get_tables2().

pb.pos

value for the progress bar. Not to be specified outside of get_overview().

pb

progress bar object. Not to be specified outside of get_overview().

Value

A sorted character vector containing the names of the fields available in the selected OpenParlData endpoint.

Examples

## Not run: 
# Get variables of OpenParlData resource "persons"
get_variables2(table = "persons")

## End(Not run)

swissparl documentation built on March 4, 2026, 9:07 a.m.