Learn R Programming

swissparl (version 0.2.2)

seating_plan: Seating plan of the National Council

Description

A dataset containing the relative locations of the seats in the Swiss National Council to display schematic seating plans. A seat is defined by 4 corner points.

Usage

seating_plan

Arguments

Format

A data frame with 800 rows and 5 variables:

SeatNumber

seat identifier.

order

corner identifier.

x

position of a corner point on the x-axis.

y

position of a corner point on the y-axis.

center_x

position of the seat center on the x-axis.

center_y

position of the seat center on the y-axis.