| get_glimpse2 | R Documentation |
get_glimpse2 retrieves the first rows of a resource provided by the
OpenParlData.ch REST API and allows a first insight into its data structure.
get_glimpse2(table, rows = 20)
table |
name of the OpenParlData resource to glimpse
into. For an overview of available endpoints use
|
rows |
number of records to download. Maximum is 1000. |
A tibble containing up to rows records. Column composition
depends on the selected OpenParlData resource.
## Not run:
# Short excerpt of OpenParlData resource "persons"
get_glimpse2(table = "persons")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.