| get_related_data2 | R Documentation |
get_related_data2 retrieves related records that are available for an
OpenParlData record via its linked resources.
get_related_data2(res, table, silent = FALSE)
res |
an OpenParlData record (typically one row) as returned by
|
table |
name of the related table to retrieve. Use
|
silent |
if |
The function downloads the related data for a specified related table and combines the results into a single tibble. If multiple entities are present, the function iterates over them and optionally displays a progress bar.
A tibble containing the related records.
## Not run:
# Retrieve one person
res <- get_data2("persons", firstname = "Gerhard", lastname = "Andrey")
# List available related tables
get_related_tables2(res)
# Retrieve related data (replace "memberships" with an available table)
get_related_data2(res, table = "memberships")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.