Learn R Programming

swissparl (version 0.2.2)

get_tables: Retrieve available tables

Description

get_tables retrieves the names of the available tables of the Swiss Parliament WebServices.

Usage

get_tables()

Arguments

Value

A character vector that contains all the names of the available tables.

Examples

Run this code
# NOT RUN {
# Get all available tables
get_tables()
# }

Run the code above in your browser using DataLab