powered by
get_tables retrieves the names of the available tables of the Swiss Parliament WebServices.
get_tables
get_tables()
A character vector that contains all the names of the available tables.
# NOT RUN { # Get all available tables get_tables() # }
Run the code above in your browser using DataLab