View source: R/get_variables.R
| get_variables | R Documentation |
get_variables retrieves the variable names of a table of the Swiss Parliament WebServices.
get_variables(table, pb.pos = NULL, pb = NULL)
table |
name of the table to be queried. For an
overview of available tables use |
pb.pos |
value for the progress bar. Not to be
specified outside of |
pb |
progress bar object. Not to be specified
outside of |
A sorted character vector containing the names of the variables.
## Not run:
# Get variables of table "Person"
get_variables(table = "Person")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.