| get_variables2 | R Documentation |
get_variables2 retrieves the field names of a resource provided by
the OpenParlData.ch REST API.
get_variables2(table, pb.pos = NULL, pb = NULL)
table |
name of the OpenParlData resource to be
queried. For an overview of available endpoints use
|
pb.pos |
value for the progress bar. Not to be
specified outside of |
pb |
progress bar object. Not to be specified outside of
|
A sorted character vector containing the names of the fields available in the selected OpenParlData endpoint.
## Not run:
# Get variables of OpenParlData resource "persons"
get_variables2(table = "persons")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.