A dataset containing the relative locations of the seats in the Swiss National Council to display schematic seating plans. A seat is defined by 4 corner points.
seating_planA data frame with 800 rows and 5 variables:
seat identifier.
corner identifier.
position of a corner point on the x-axis.
position of a corner point on the y-axis.
position of the seat center on the x-axis.
position of the seat center on the y-axis.